# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ChangeRelationTypeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'public_id': 'str',
        'source_type_id': 'str',
        'role': 'str',
        'target_type_id': 'str',
        'co_role': 'str',
        'description': 'str'
    }

    attribute_map = {
        'id': 'id',
        'public_id': 'publicId',
        'source_type_id': 'sourceTypeId',
        'role': 'role',
        'target_type_id': 'targetTypeId',
        'co_role': 'coRole',
        'description': 'description'
    }

    def __init__(self, id=None, public_id=None, source_type_id=None, role=None, target_type_id=None, co_role=None, description=None):  # noqa: E501
        """ChangeRelationTypeRequest - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._public_id = None
        self._source_type_id = None
        self._role = None
        self._target_type_id = None
        self._co_role = None
        self._description = None
        self.discriminator = None
        self.id = id
        if public_id is not None:
            self.public_id = public_id
        if source_type_id is not None:
            self.source_type_id = source_type_id
        if role is not None:
            self.role = role
        if target_type_id is not None:
            self.target_type_id = target_type_id
        if co_role is not None:
            self.co_role = co_role
        if description is not None:
            self.description = description

    @property
    def id(self):
        """Gets the id of this ChangeRelationTypeRequest.  # noqa: E501

        The ID of the Relation Type to be changed. Silently ignored if the ID is provided as path parameter of the request.  # noqa: E501

        :return: The id of this ChangeRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ChangeRelationTypeRequest.

        The ID of the Relation Type to be changed. Silently ignored if the ID is provided as path parameter of the request.  # noqa: E501

        :param id: The id of this ChangeRelationTypeRequest.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def public_id(self):
        """Gets the public_id of this ChangeRelationTypeRequest.  # noqa: E501

        The new public id for the Relation Type. It must be unique within all Relation Types. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". WARNING : The public id should only be changed with extreme caution, since it can break existing customizations. The only valid use case is to change it after creation of the type, if no public id was specified, and the generated proposal is not acceptable.  # noqa: E501

        :return: The public_id of this ChangeRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this ChangeRelationTypeRequest.

        The new public id for the Relation Type. It must be unique within all Relation Types. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". WARNING : The public id should only be changed with extreme caution, since it can break existing customizations. The only valid use case is to change it after creation of the type, if no public id was specified, and the generated proposal is not acceptable.  # noqa: E501

        :param public_id: The public_id of this ChangeRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def source_type_id(self):
        """Gets the source_type_id of this ChangeRelationTypeRequest.  # noqa: E501

        The ID of the new source type for the Relation Type.  # noqa: E501

        :return: The source_type_id of this ChangeRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._source_type_id

    @source_type_id.setter
    def source_type_id(self, source_type_id):
        """Sets the source_type_id of this ChangeRelationTypeRequest.

        The ID of the new source type for the Relation Type.  # noqa: E501

        :param source_type_id: The source_type_id of this ChangeRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._source_type_id = source_type_id

    @property
    def role(self):
        """Gets the role of this ChangeRelationTypeRequest.  # noqa: E501

        The new name of the role that the source plays.  # noqa: E501

        :return: The role of this ChangeRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this ChangeRelationTypeRequest.

        The new name of the role that the source plays.  # noqa: E501

        :param role: The role of this ChangeRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def target_type_id(self):
        """Gets the target_type_id of this ChangeRelationTypeRequest.  # noqa: E501

        The ID of the new target type for the Relation Type.  # noqa: E501

        :return: The target_type_id of this ChangeRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._target_type_id

    @target_type_id.setter
    def target_type_id(self, target_type_id):
        """Sets the target_type_id of this ChangeRelationTypeRequest.

        The ID of the new target type for the Relation Type.  # noqa: E501

        :param target_type_id: The target_type_id of this ChangeRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._target_type_id = target_type_id

    @property
    def co_role(self):
        """Gets the co_role of this ChangeRelationTypeRequest.  # noqa: E501

        The new name of the role that the target plays.  # noqa: E501

        :return: The co_role of this ChangeRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._co_role

    @co_role.setter
    def co_role(self, co_role):
        """Sets the co_role of this ChangeRelationTypeRequest.

        The new name of the role that the target plays.  # noqa: E501

        :param co_role: The co_role of this ChangeRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._co_role = co_role

    @property
    def description(self):
        """Gets the description of this ChangeRelationTypeRequest.  # noqa: E501

        The new description of the Relation Type.  # noqa: E501

        :return: The description of this ChangeRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ChangeRelationTypeRequest.

        The new description of the Relation Type.  # noqa: E501

        :param description: The description of this ChangeRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChangeRelationTypeRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeRelationTypeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class DiagramPicturesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_diagram_picture(self, **kwargs):  # noqa: E501
        """Adds a diagram picture.  # noqa: E501

        Take a diagram picture for a given asset and diagram view. A diagram picture is a copy of traceability diagram (result diagram) at a given time (for more information on traceability diagram check DGC User Guide).  The motivation behind diagram picture is to be able to reopen them at a later point in time and be able to see them them exactly as they were created. This feature is not possible for result diagram which are always showing the current situation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_diagram_picture(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddDiagramPictureRequest body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_diagram_picture_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_diagram_picture_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_diagram_picture_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a diagram picture.  # noqa: E501

        Take a diagram picture for a given asset and diagram view. A diagram picture is a copy of traceability diagram (result diagram) at a given time (for more information on traceability diagram check DGC User Guide).  The motivation behind diagram picture is to be able to reopen them at a later point in time and be able to see them them exactly as they were created. This feature is not possible for result diagram which are always showing the current situation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_diagram_picture_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddDiagramPictureRequest body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_diagram_picture" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/diagramPictures', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'created_by': 'str',
        'created_on': 'int',
        'last_modified_by': 'str',
        'last_modified_on': 'int',
        'system': 'bool',
        'resource_type': 'str',
        'user_name': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email_address': 'str',
        'gender': 'str',
        'language': 'str',
        'additional_email_addresses': 'list[Email]',
        'phone_numbers': 'list[PhoneNumber]',
        'instant_messaging_accounts': 'list[InstantMessagingAccount]',
        'websites': 'list[Website]',
        'addresses': 'list[Address]',
        'activated': 'bool',
        'enabled': 'bool',
        'ldap_user': 'bool',
        'user_source': 'str',
        'guest_user': 'bool',
        'api_user': 'bool',
        'license_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_on': 'lastModifiedOn',
        'system': 'system',
        'resource_type': 'resourceType',
        'user_name': 'userName',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email_address': 'emailAddress',
        'gender': 'gender',
        'language': 'language',
        'additional_email_addresses': 'additionalEmailAddresses',
        'phone_numbers': 'phoneNumbers',
        'instant_messaging_accounts': 'instantMessagingAccounts',
        'websites': 'websites',
        'addresses': 'addresses',
        'activated': 'activated',
        'enabled': 'enabled',
        'ldap_user': 'ldapUser',
        'user_source': 'userSource',
        'guest_user': 'guestUser',
        'api_user': 'apiUser',
        'license_type': 'licenseType'
    }

    def __init__(self, id=None, created_by=None, created_on=None, last_modified_by=None, last_modified_on=None, system=None, resource_type=None, user_name=None, first_name=None, last_name=None, email_address=None, gender=None, language=None, additional_email_addresses=None, phone_numbers=None, instant_messaging_accounts=None, websites=None, addresses=None, activated=None, enabled=None, ldap_user=None, user_source=None, guest_user=None, api_user=None, license_type=None):  # noqa: E501
        """User - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_by = None
        self._created_on = None
        self._last_modified_by = None
        self._last_modified_on = None
        self._system = None
        self._resource_type = None
        self._user_name = None
        self._first_name = None
        self._last_name = None
        self._email_address = None
        self._gender = None
        self._language = None
        self._additional_email_addresses = None
        self._phone_numbers = None
        self._instant_messaging_accounts = None
        self._websites = None
        self._addresses = None
        self._activated = None
        self._enabled = None
        self._ldap_user = None
        self._user_source = None
        self._guest_user = None
        self._api_user = None
        self._license_type = None
        self.discriminator = None
        self.id = id
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_on is not None:
            self.last_modified_on = last_modified_on
        if system is not None:
            self.system = system
        self.resource_type = resource_type
        if user_name is not None:
            self.user_name = user_name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email_address is not None:
            self.email_address = email_address
        if gender is not None:
            self.gender = gender
        if language is not None:
            self.language = language
        if additional_email_addresses is not None:
            self.additional_email_addresses = additional_email_addresses
        if phone_numbers is not None:
            self.phone_numbers = phone_numbers
        if instant_messaging_accounts is not None:
            self.instant_messaging_accounts = instant_messaging_accounts
        if websites is not None:
            self.websites = websites
        if addresses is not None:
            self.addresses = addresses
        if activated is not None:
            self.activated = activated
        if enabled is not None:
            self.enabled = enabled
        if ldap_user is not None:
            self.ldap_user = ldap_user
        if user_source is not None:
            self.user_source = user_source
        if guest_user is not None:
            self.guest_user = guest_user
        if api_user is not None:
            self.api_user = api_user
        if license_type is not None:
            self.license_type = license_type

    @property
    def id(self):
        """Gets the id of this User.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this User.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this User.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_by(self):
        """Gets the created_by of this User.  # noqa: E501

        The id of the user that created this resource.  # noqa: E501

        :return: The created_by of this User.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this User.

        The id of the user that created this resource.  # noqa: E501

        :param created_by: The created_by of this User.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this User.  # noqa: E501

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :return: The created_on of this User.  # noqa: E501
        :rtype: int
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this User.

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :param created_on: The created_on of this User.  # noqa: E501
        :type: int
        """

        self._created_on = created_on

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this User.  # noqa: E501

        The id of the user who modified this resource the last time.  # noqa: E501

        :return: The last_modified_by of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this User.

        The id of the user who modified this resource the last time.  # noqa: E501

        :param last_modified_by: The last_modified_by of this User.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_on(self):
        """Gets the last_modified_on of this User.  # noqa: E501

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :return: The last_modified_on of this User.  # noqa: E501
        :rtype: int
        """
        return self._last_modified_on

    @last_modified_on.setter
    def last_modified_on(self, last_modified_on):
        """Sets the last_modified_on of this User.

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :param last_modified_on: The last_modified_on of this User.  # noqa: E501
        :type: int
        """

        self._last_modified_on = last_modified_on

    @property
    def system(self):
        """Gets the system of this User.  # noqa: E501

        Whether this is a system resource or not.  # noqa: E501

        :return: The system of this User.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this User.

        Whether this is a system resource or not.  # noqa: E501

        :param system: The system of this User.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def resource_type(self):
        """Gets the resource_type of this User.  # noqa: E501

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :return: The resource_type of this User.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this User.

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :param resource_type: The resource_type of this User.  # noqa: E501
        :type: str
        """
        if resource_type is None:
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if resource_type not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def user_name(self):
        """Gets the user_name of this User.  # noqa: E501

        The user name.  # noqa: E501

        :return: The user_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this User.

        The user name.  # noqa: E501

        :param user_name: The user_name of this User.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501

        The first name of the user.  # noqa: E501

        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.

        The first name of the user.  # noqa: E501

        :param first_name: The first_name of this User.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501

        The last name of the user.  # noqa: E501

        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.

        The last name of the user.  # noqa: E501

        :param last_name: The last_name of this User.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email_address(self):
        """Gets the email_address of this User.  # noqa: E501

        The main email address.  # noqa: E501

        :return: The email_address of this User.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this User.

        The main email address.  # noqa: E501

        :param email_address: The email_address of this User.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def gender(self):
        """Gets the gender of this User.  # noqa: E501

        The gender of the user.  # noqa: E501

        :return: The gender of this User.  # noqa: E501
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this User.

        The gender of the user.  # noqa: E501

        :param gender: The gender of this User.  # noqa: E501
        :type: str
        """
        allowed_values = ["MALE", "FEMALE", "UNKNOWN"]  # noqa: E501
        if gender not in allowed_values:
            raise ValueError(
                "Invalid value for `gender` ({0}), must be one of {1}"  # noqa: E501
                .format(gender, allowed_values)
            )

        self._gender = gender

    @property
    def language(self):
        """Gets the language of this User.  # noqa: E501

        The current language preference for this user.  # noqa: E501

        :return: The language of this User.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this User.

        The current language preference for this user.  # noqa: E501

        :param language: The language of this User.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def additional_email_addresses(self):
        """Gets the additional_email_addresses of this User.  # noqa: E501

        The list of additional email addresses.  # noqa: E501

        :return: The additional_email_addresses of this User.  # noqa: E501
        :rtype: list[Email]
        """
        return self._additional_email_addresses

    @additional_email_addresses.setter
    def additional_email_addresses(self, additional_email_addresses):
        """Sets the additional_email_addresses of this User.

        The list of additional email addresses.  # noqa: E501

        :param additional_email_addresses: The additional_email_addresses of this User.  # noqa: E501
        :type: list[Email]
        """

        self._additional_email_addresses = additional_email_addresses

    @property
    def phone_numbers(self):
        """Gets the phone_numbers of this User.  # noqa: E501

        The list of phone numbers.  # noqa: E501

        :return: The phone_numbers of this User.  # noqa: E501
        :rtype: list[PhoneNumber]
        """
        return self._phone_numbers

    @phone_numbers.setter
    def phone_numbers(self, phone_numbers):
        """Sets the phone_numbers of this User.

        The list of phone numbers.  # noqa: E501

        :param phone_numbers: The phone_numbers of this User.  # noqa: E501
        :type: list[PhoneNumber]
        """

        self._phone_numbers = phone_numbers

    @property
    def instant_messaging_accounts(self):
        """Gets the instant_messaging_accounts of this User.  # noqa: E501

        The list of instant messaging accounts.  # noqa: E501

        :return: The instant_messaging_accounts of this User.  # noqa: E501
        :rtype: list[InstantMessagingAccount]
        """
        return self._instant_messaging_accounts

    @instant_messaging_accounts.setter
    def instant_messaging_accounts(self, instant_messaging_accounts):
        """Sets the instant_messaging_accounts of this User.

        The list of instant messaging accounts.  # noqa: E501

        :param instant_messaging_accounts: The instant_messaging_accounts of this User.  # noqa: E501
        :type: list[InstantMessagingAccount]
        """

        self._instant_messaging_accounts = instant_messaging_accounts

    @property
    def websites(self):
        """Gets the websites of this User.  # noqa: E501

        The list of websites.  # noqa: E501

        :return: The websites of this User.  # noqa: E501
        :rtype: list[Website]
        """
        return self._websites

    @websites.setter
    def websites(self, websites):
        """Sets the websites of this User.

        The list of websites.  # noqa: E501

        :param websites: The websites of this User.  # noqa: E501
        :type: list[Website]
        """

        self._websites = websites

    @property
    def addresses(self):
        """Gets the addresses of this User.  # noqa: E501

        The list of addresses.  # noqa: E501

        :return: The addresses of this User.  # noqa: E501
        :rtype: list[Address]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this User.

        The list of addresses.  # noqa: E501

        :param addresses: The addresses of this User.  # noqa: E501
        :type: list[Address]
        """

        self._addresses = addresses

    @property
    def activated(self):
        """Gets the activated of this User.  # noqa: E501

        Whether this user account is already activated or not.  # noqa: E501

        :return: The activated of this User.  # noqa: E501
        :rtype: bool
        """
        return self._activated

    @activated.setter
    def activated(self, activated):
        """Sets the activated of this User.

        Whether this user account is already activated or not.  # noqa: E501

        :param activated: The activated of this User.  # noqa: E501
        :type: bool
        """

        self._activated = activated

    @property
    def enabled(self):
        """Gets the enabled of this User.  # noqa: E501

        Whether this user account is already enabled or not.  # noqa: E501

        :return: The enabled of this User.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this User.

        Whether this user account is already enabled or not.  # noqa: E501

        :param enabled: The enabled of this User.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def ldap_user(self):
        """Gets the ldap_user of this User.  # noqa: E501

        Whether this is an LDAP user or not.  # noqa: E501

        :return: The ldap_user of this User.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_user

    @ldap_user.setter
    def ldap_user(self, ldap_user):
        """Sets the ldap_user of this User.

        Whether this is an LDAP user or not.  # noqa: E501

        :param ldap_user: The ldap_user of this User.  # noqa: E501
        :type: bool
        """

        self._ldap_user = ldap_user

    @property
    def user_source(self):
        """Gets the user_source of this User.  # noqa: E501


        :return: The user_source of this User.  # noqa: E501
        :rtype: str
        """
        return self._user_source

    @user_source.setter
    def user_source(self, user_source):
        """Sets the user_source of this User.


        :param user_source: The user_source of this User.  # noqa: E501
        :type: str
        """
        allowed_values = ["INTERNAL", "LDAP", "SSO"]  # noqa: E501
        if user_source not in allowed_values:
            raise ValueError(
                "Invalid value for `user_source` ({0}), must be one of {1}"  # noqa: E501
                .format(user_source, allowed_values)
            )

        self._user_source = user_source

    @property
    def guest_user(self):
        """Gets the guest_user of this User.  # noqa: E501

        Whether this is a guest user or not.  # noqa: E501

        :return: The guest_user of this User.  # noqa: E501
        :rtype: bool
        """
        return self._guest_user

    @guest_user.setter
    def guest_user(self, guest_user):
        """Sets the guest_user of this User.

        Whether this is a guest user or not.  # noqa: E501

        :param guest_user: The guest_user of this User.  # noqa: E501
        :type: bool
        """

        self._guest_user = guest_user

    @property
    def api_user(self):
        """Gets the api_user of this User.  # noqa: E501

        Whether this is API user or not. This field is no longer used and will be removed in the future.  # noqa: E501

        :return: The api_user of this User.  # noqa: E501
        :rtype: bool
        """
        return self._api_user

    @api_user.setter
    def api_user(self, api_user):
        """Sets the api_user of this User.

        Whether this is API user or not. This field is no longer used and will be removed in the future.  # noqa: E501

        :param api_user: The api_user of this User.  # noqa: E501
        :type: bool
        """

        self._api_user = api_user

    @property
    def license_type(self):
        """Gets the license_type of this User.  # noqa: E501

        This field represents the given license which is no longer used, so the method no longer returns useful data and will be removed in the future. To retrieve the user's required license type based on their permissions, please use GET /users/{userId}/licenseType  # noqa: E501

        :return: The license_type of this User.  # noqa: E501
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """Sets the license_type of this User.

        This field represents the given license which is no longer used, so the method no longer returns useful data and will be removed in the future. To retrieve the user's required license type based on their permissions, please use GET /users/{userId}/licenseType  # noqa: E501

        :param license_type: The license_type of this User.  # noqa: E501
        :type: str
        """
        allowed_values = ["CONSUMER", "AUTHOR"]  # noqa: E501
        if license_type not in allowed_values:
            raise ValueError(
                "Invalid value for `license_type` ({0}), must be one of {1}"  # noqa: E501
                .format(license_type, allowed_values)
            )

        self._license_type = license_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class FilesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_files(self, **kwargs):  # noqa: E501
        """Upload files  # noqa: E501

        Upload files  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_files(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file:
        :return: list[FileInfoImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_files_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_files_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_files_with_http_info(self, **kwargs):  # noqa: E501
        """Upload files  # noqa: E501

        Upload files  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_files_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file:
        :return: list[FileInfoImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_files" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[FileInfoImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_file(self, file_id, **kwargs):  # noqa: E501
        """Delete file  # noqa: E501

        Delete file for a given Id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: the id of the file (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_file_with_http_info(file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_file_with_http_info(file_id, **kwargs)  # noqa: E501
            return data

    def delete_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Delete file  # noqa: E501

        Delete file for a given Id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: the id of the file (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `delete_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in params:
            path_params['fileId'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files/{fileId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_files(self, **kwargs):  # noqa: E501
        """Delete multiple files  # noqa: E501

        Deletes files that are older than the given time to live.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_files(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int time_to_live:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_files_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.delete_files_with_http_info(**kwargs)  # noqa: E501
            return data

    def delete_files_with_http_info(self, **kwargs):  # noqa: E501
        """Delete multiple files  # noqa: E501

        Deletes files that are older than the given time to live.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_files_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int time_to_live:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['time_to_live']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_files" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'time_to_live' in params:
            query_params.append(('timeToLive', params['time_to_live']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file(self, file_id, **kwargs):  # noqa: E501
        """Download file  # noqa: E501

        Downloads file identified by given id.  Keep in mind to use GET /attachments/{attachmentId}/file instead of this endpoint when you want to get the file of an attachment.  A File and its id can be temporary so it's possible this endpoint will not get you the desired file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: the id of the file (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_file_with_http_info(file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_file_with_http_info(file_id, **kwargs)  # noqa: E501
            return data

    def get_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Download file  # noqa: E501

        Downloads file identified by given id.  Keep in mind to use GET /attachments/{attachmentId}/file instead of this endpoint when you want to get the file of an attachment.  A File and its id can be temporary so it's possible this endpoint will not get you the desired file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: the id of the file (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `get_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in params:
            path_params['fileId'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files/{fileId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file_info(self, file_id, **kwargs):  # noqa: E501
        """Get file information  # noqa: E501

        Returns information about the file identified by given id. Keep in mind to use GET /attachments/{attachmentId} instead of this endpoint when you want to get information of an attachment. A File and its id can be temporary so it's possible this endpoint will not get you the information of the desired file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: the id of the file (required)
        :return: ScopeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_file_info_with_http_info(file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_file_info_with_http_info(file_id, **kwargs)  # noqa: E501
            return data

    def get_file_info_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Get file information  # noqa: E501

        Returns information about the file identified by given id. Keep in mind to use GET /attachments/{attachmentId} instead of this endpoint when you want to get information of an attachment. A File and its id can be temporary so it's possible this endpoint will not get you the information of the desired file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_info_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: the id of the file (required)
        :return: ScopeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `get_file_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in params:
            path_params['fileId'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files/{fileId}/info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScopeImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddViewPermissionRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'user_group_id': 'str',
        'base_resource': 'ResourceReference'
    }

    attribute_map = {
        'user_id': 'userId',
        'user_group_id': 'userGroupId',
        'base_resource': 'baseResource'
    }

    def __init__(self, user_id=None, user_group_id=None, base_resource=None):  # noqa: E501
        """AddViewPermissionRequest - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._user_group_id = None
        self._base_resource = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        if user_group_id is not None:
            self.user_group_id = user_group_id
        self.base_resource = base_resource

    @property
    def user_id(self):
        """Gets the user_id of this AddViewPermissionRequest.  # noqa: E501

        The userId of the person who should receive the view permission. Either this or the userGroupId is required.  # noqa: E501

        :return: The user_id of this AddViewPermissionRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AddViewPermissionRequest.

        The userId of the person who should receive the view permission. Either this or the userGroupId is required.  # noqa: E501

        :param user_id: The user_id of this AddViewPermissionRequest.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_group_id(self):
        """Gets the user_group_id of this AddViewPermissionRequest.  # noqa: E501

        The userGroupId of the group that should receive the view permission.  Either this or the userId is required.  # noqa: E501

        :return: The user_group_id of this AddViewPermissionRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_group_id

    @user_group_id.setter
    def user_group_id(self, user_group_id):
        """Sets the user_group_id of this AddViewPermissionRequest.

        The userGroupId of the group that should receive the view permission.  Either this or the userId is required.  # noqa: E501

        :param user_group_id: The user_group_id of this AddViewPermissionRequest.  # noqa: E501
        :type: str
        """

        self._user_group_id = user_group_id

    @property
    def base_resource(self):
        """Gets the base_resource of this AddViewPermissionRequest.  # noqa: E501


        :return: The base_resource of this AddViewPermissionRequest.  # noqa: E501
        :rtype: ResourceReference
        """
        return self._base_resource

    @base_resource.setter
    def base_resource(self, base_resource):
        """Sets the base_resource of this AddViewPermissionRequest.


        :param base_resource: The base_resource of this AddViewPermissionRequest.  # noqa: E501
        :type: ResourceReference
        """
        if base_resource is None:
            raise ValueError("Invalid value for `base_resource`, must not be `None`")  # noqa: E501

        self._base_resource = base_resource

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddViewPermissionRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddViewPermissionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SetAssetRelationsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type_id': 'str',
        'related_asset_ids': 'list[str]',
        'relation_direction': 'str'
    }

    attribute_map = {
        'type_id': 'typeId',
        'related_asset_ids': 'relatedAssetIds',
        'relation_direction': 'relationDirection'
    }

    def __init__(self, type_id=None, related_asset_ids=None, relation_direction=None):  # noqa: E501
        """SetAssetRelationsRequest - a model defined in Swagger"""  # noqa: E501
        self._type_id = None
        self._related_asset_ids = None
        self._relation_direction = None
        self.discriminator = None
        self.type_id = type_id
        self.related_asset_ids = related_asset_ids
        self.relation_direction = relation_direction

    @property
    def type_id(self):
        """Gets the type_id of this SetAssetRelationsRequest.  # noqa: E501

        The ID of the relation type for the relations to be set.  # noqa: E501

        :return: The type_id of this SetAssetRelationsRequest.  # noqa: E501
        :rtype: str
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this SetAssetRelationsRequest.

        The ID of the relation type for the relations to be set.  # noqa: E501

        :param type_id: The type_id of this SetAssetRelationsRequest.  # noqa: E501
        :type: str
        """
        if type_id is None:
            raise ValueError("Invalid value for `type_id`, must not be `None`")  # noqa: E501

        self._type_id = type_id

    @property
    def related_asset_ids(self):
        """Gets the related_asset_ids of this SetAssetRelationsRequest.  # noqa: E501

        The IDs of the related assets.  # noqa: E501

        :return: The related_asset_ids of this SetAssetRelationsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._related_asset_ids

    @related_asset_ids.setter
    def related_asset_ids(self, related_asset_ids):
        """Sets the related_asset_ids of this SetAssetRelationsRequest.

        The IDs of the related assets.  # noqa: E501

        :param related_asset_ids: The related_asset_ids of this SetAssetRelationsRequest.  # noqa: E501
        :type: list[str]
        """
        if related_asset_ids is None:
            raise ValueError("Invalid value for `related_asset_ids`, must not be `None`")  # noqa: E501

        self._related_asset_ids = related_asset_ids

    @property
    def relation_direction(self):
        """Gets the relation_direction of this SetAssetRelationsRequest.  # noqa: E501

        The relation direction. If TO_SOURCE then related assets will become source assets. Otherwise they will become target assets for created relations.  # noqa: E501

        :return: The relation_direction of this SetAssetRelationsRequest.  # noqa: E501
        :rtype: str
        """
        return self._relation_direction

    @relation_direction.setter
    def relation_direction(self, relation_direction):
        """Sets the relation_direction of this SetAssetRelationsRequest.

        The relation direction. If TO_SOURCE then related assets will become source assets. Otherwise they will become target assets for created relations.  # noqa: E501

        :param relation_direction: The relation_direction of this SetAssetRelationsRequest.  # noqa: E501
        :type: str
        """
        if relation_direction is None:
            raise ValueError("Invalid value for `relation_direction`, must not be `None`")  # noqa: E501
        allowed_values = ["TO_TARGET", "TO_SOURCE"]  # noqa: E501
        if relation_direction not in allowed_values:
            raise ValueError(
                "Invalid value for `relation_direction` ({0}), must be one of {1}"  # noqa: E501
                .format(relation_direction, allowed_values)
            )

        self._relation_direction = relation_direction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SetAssetRelationsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SetAssetRelationsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddScopeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'public_id': 'str',
        'name': 'str',
        'description': 'str',
        'domain_ids': 'list[str]',
        'community_ids': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'public_id': 'publicId',
        'name': 'name',
        'description': 'description',
        'domain_ids': 'domainIds',
        'community_ids': 'communityIds'
    }

    def __init__(self, id=None, public_id=None, name=None, description=None, domain_ids=None, community_ids=None):  # noqa: E501
        """AddScopeRequest - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._public_id = None
        self._name = None
        self._description = None
        self._domain_ids = None
        self._community_ids = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if public_id is not None:
            self.public_id = public_id
        self.name = name
        if description is not None:
            self.description = description
        if domain_ids is not None:
            self.domain_ids = domain_ids
        if community_ids is not None:
            self.community_ids = community_ids

    @property
    def id(self):
        """Gets the id of this AddScopeRequest.  # noqa: E501

        The ID of the new scope. Should be unique within all scopes.<br/>It should have a format of universally unique identifier (UUID) and should not start with<br/><code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :return: The id of this AddScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddScopeRequest.

        The ID of the new scope. Should be unique within all scopes.<br/>It should have a format of universally unique identifier (UUID) and should not start with<br/><code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :param id: The id of this AddScopeRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def public_id(self):
        """Gets the public_id of this AddScopeRequest.  # noqa: E501

        The public id that will be assigned to the new Scope. It must be unique within all Asset Types, Complex Relation Types, Domain Types and Scopes. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". If no public id is provided, a valid public id will be generated.  # noqa: E501

        :return: The public_id of this AddScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this AddScopeRequest.

        The public id that will be assigned to the new Scope. It must be unique within all Asset Types, Complex Relation Types, Domain Types and Scopes. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". If no public id is provided, a valid public id will be generated.  # noqa: E501

        :param public_id: The public_id of this AddScopeRequest.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def name(self):
        """Gets the name of this AddScopeRequest.  # noqa: E501

        The name of the new scope  # noqa: E501

        :return: The name of this AddScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddScopeRequest.

        The name of the new scope  # noqa: E501

        :param name: The name of this AddScopeRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this AddScopeRequest.  # noqa: E501

        The description of the new scope  # noqa: E501

        :return: The description of this AddScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddScopeRequest.

        The description of the new scope  # noqa: E501

        :param description: The description of this AddScopeRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def domain_ids(self):
        """Gets the domain_ids of this AddScopeRequest.  # noqa: E501

        The list of IDs for domains assigned to the new scope  # noqa: E501

        :return: The domain_ids of this AddScopeRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._domain_ids

    @domain_ids.setter
    def domain_ids(self, domain_ids):
        """Sets the domain_ids of this AddScopeRequest.

        The list of IDs for domains assigned to the new scope  # noqa: E501

        :param domain_ids: The domain_ids of this AddScopeRequest.  # noqa: E501
        :type: list[str]
        """

        self._domain_ids = domain_ids

    @property
    def community_ids(self):
        """Gets the community_ids of this AddScopeRequest.  # noqa: E501

        The list of IDs for communities assigned to the new scope  # noqa: E501

        :return: The community_ids of this AddScopeRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._community_ids

    @community_ids.setter
    def community_ids(self, community_ids):
        """Sets the community_ids of this AddScopeRequest.

        The list of IDs for communities assigned to the new scope  # noqa: E501

        :param community_ids: The community_ids of this AddScopeRequest.  # noqa: E501
        :type: list[str]
        """

        self._community_ids = community_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddScopeRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddScopeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ChangeComplexRelationRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'legs': 'list[ComplexRelationLegRequest]',
        'relations': 'dict(str, list[RelatedAssetId])',
        'attributes': 'dict(str, list[AttributeValue])'
    }

    attribute_map = {
        'legs': 'legs',
        'relations': 'relations',
        'attributes': 'attributes'
    }

    def __init__(self, legs=None, relations=None, attributes=None):  # noqa: E501
        """ChangeComplexRelationRequest - a model defined in Swagger"""  # noqa: E501
        self._legs = None
        self._relations = None
        self._attributes = None
        self.discriminator = None
        if legs is not None:
            self.legs = legs
        if relations is not None:
            self.relations = relations
        if attributes is not None:
            self.attributes = attributes

    @property
    def legs(self):
        """Gets the legs of this ChangeComplexRelationRequest.  # noqa: E501

        The new list of legs that the changed complex relation should contain.  # noqa: E501

        :return: The legs of this ChangeComplexRelationRequest.  # noqa: E501
        :rtype: list[ComplexRelationLegRequest]
        """
        return self._legs

    @legs.setter
    def legs(self, legs):
        """Sets the legs of this ChangeComplexRelationRequest.

        The new list of legs that the changed complex relation should contain.  # noqa: E501

        :param legs: The legs of this ChangeComplexRelationRequest.  # noqa: E501
        :type: list[ComplexRelationLegRequest]
        """

        self._legs = legs

    @property
    def relations(self):
        """Gets the relations of this ChangeComplexRelationRequest.  # noqa: E501

        The new relations that the new complex relation should contain.  # noqa: E501

        :return: The relations of this ChangeComplexRelationRequest.  # noqa: E501
        :rtype: dict(str, list[RelatedAssetId])
        """
        return self._relations

    @relations.setter
    def relations(self, relations):
        """Sets the relations of this ChangeComplexRelationRequest.

        The new relations that the new complex relation should contain.  # noqa: E501

        :param relations: The relations of this ChangeComplexRelationRequest.  # noqa: E501
        :type: dict(str, list[RelatedAssetId])
        """

        self._relations = relations

    @property
    def attributes(self):
        """Gets the attributes of this ChangeComplexRelationRequest.  # noqa: E501

        The new attributes that the new complex relation should contain.  # noqa: E501

        :return: The attributes of this ChangeComplexRelationRequest.  # noqa: E501
        :rtype: dict(str, list[AttributeValue])
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this ChangeComplexRelationRequest.

        The new attributes that the new complex relation should contain.  # noqa: E501

        :param attributes: The attributes of this ChangeComplexRelationRequest.  # noqa: E501
        :type: dict(str, list[AttributeValue])
        """

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChangeComplexRelationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeComplexRelationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class MappingsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_mapping(self, **kwargs):  # noqa: E501
        """Adds a new mapping.  # noqa: E501

        Adds a new mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_mapping(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddMappingRequest body: The properties of the mapping to be added.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_mapping_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_mapping_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_mapping_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new mapping.  # noqa: E501

        Adds a new mapping.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_mapping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddMappingRequest body: The properties of the mapping to be added.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_mapping" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_mappings(self, **kwargs):  # noqa: E501
        """Adds new mappings.  # noqa: E501

        Adds new mappings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_mappings(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddMappingRequest] body: The properties of the mappings to be added.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_mappings_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_mappings_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_mappings_with_http_info(self, **kwargs):  # noqa: E501
        """Adds new mappings.  # noqa: E501

        Adds new mappings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_mappings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddMappingRequest] body: The properties of the mappings to be added.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_mappings" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Mapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mapping(self, mapping_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its id.  # noqa: E501

        Changes the mapping identified by its <code>id</code>.<p>Change the mapping identified by its <code>id</code> with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mapping_id: The ID of the mapping to be changed. (required)
        :param ChangeMappingRequest body: The properties of the mapping to be changed.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501
            return data

    def change_mapping_with_http_info(self, mapping_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its id.  # noqa: E501

        Changes the mapping identified by its <code>id</code>.<p>Change the mapping identified by its <code>id</code> with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_with_http_info(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mapping_id: The ID of the mapping to be changed. (required)
        :param ChangeMappingRequest body: The properties of the mapping to be changed.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['mapping_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mapping" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `change_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'mapping_id' in params:
            path_params['mappingId'] = params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/{mappingId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mapping_by_external_entity(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its external ids.  # noqa: E501

        Changes the mapping identified by its external <code>id</code>s.<p>Changes the mapping identified by its external <code>id</code>s with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_by_external_entity(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The external system ID of the mapping to be changed. (required)
        :param str external_entity_id: The external entity ID of the mapping to be changed. (required)
        :param ChangeMappingByExternalEntityRequest body: The properties of the mapping to be changed.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501
            return data

    def change_mapping_by_external_entity_with_http_info(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its external ids.  # noqa: E501

        Changes the mapping identified by its external <code>id</code>s.<p>Changes the mapping identified by its external <code>id</code>s with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The external system ID of the mapping to be changed. (required)
        :param str external_entity_id: The external entity ID of the mapping to be changed. (required)
        :param ChangeMappingByExternalEntityRequest body: The properties of the mapping to be changed.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_system_id', 'external_entity_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mapping_by_external_entity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if ('external_system_id' not in params or
                params['external_system_id'] is None):
            raise ValueError("Missing the required parameter `external_system_id` when calling `change_mapping_by_external_entity`")  # noqa: E501
        # verify the required parameter 'external_entity_id' is set
        if ('external_entity_id' not in params or
                params['external_entity_id'] is None):
            raise ValueError("Missing the required parameter `external_entity_id` when calling `change_mapping_by_external_entity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in params:
            path_params['externalSystemId'] = params['external_system_id']  # noqa: E501
        if 'external_entity_id' in params:
            path_params['externalEntityId'] = params['external_entity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/externalEntity/{externalEntityId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mapping_by_mapped_resource(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its external system id and mapped resource id.  # noqa: E501

        Changes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.<p>Changes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code> with the information that is present in the requests. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_by_mapped_resource(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The external system id of the mapping to be changed. (required)
        :param str mapped_resource_id: The mapped resource id of the mapping to be changed. (required)
        :param ChangeMappingByMappedResourceRequest body: The properties of the mapping to be changed.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501
            return data

    def change_mapping_by_mapped_resource_with_http_info(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Changes the mapping identified by its external system id and mapped resource id.  # noqa: E501

        Changes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.<p>Changes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code> with the information that is present in the requests. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The external system id of the mapping to be changed. (required)
        :param str mapped_resource_id: The mapped resource id of the mapping to be changed. (required)
        :param ChangeMappingByMappedResourceRequest body: The properties of the mapping to be changed.
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_system_id', 'mapped_resource_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mapping_by_mapped_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if ('external_system_id' not in params or
                params['external_system_id'] is None):
            raise ValueError("Missing the required parameter `external_system_id` when calling `change_mapping_by_mapped_resource`")  # noqa: E501
        # verify the required parameter 'mapped_resource_id' is set
        if ('mapped_resource_id' not in params or
                params['mapped_resource_id'] is None):
            raise ValueError("Missing the required parameter `mapped_resource_id` when calling `change_mapping_by_mapped_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in params:
            path_params['externalSystemId'] = params['external_system_id']  # noqa: E501
        if 'mapped_resource_id' in params:
            path_params['mappedResourceId'] = params['mapped_resource_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/mappedResource/{mappedResourceId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mappings(self, **kwargs):  # noqa: E501
        """Changes multiple mappings identified by their ids.  # noqa: E501

        Changes multiple mappings identified by their <code>id</code>s.<p>Change the mappings identified by its <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeMappingRequest] body: The properties of the mappings to be changed.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_mappings_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.change_mappings_with_http_info(**kwargs)  # noqa: E501
            return data

    def change_mappings_with_http_info(self, **kwargs):  # noqa: E501
        """Changes multiple mappings identified by their ids.  # noqa: E501

        Changes multiple mappings identified by their <code>id</code>s.<p>Change the mappings identified by its <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeMappingRequest] body: The properties of the mappings to be changed.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mappings" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Mapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mappings_by_external_entities(self, **kwargs):  # noqa: E501
        """Changes the mappings identified by their external ids.  # noqa: E501

        Changes the mappings identified by their external <code>id</code>s.<p>Changes the mappings identified by their external <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_by_external_entities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeMappingByExternalEntityRequest] body: The properties of the mappings to be changed.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_mappings_by_external_entities_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.change_mappings_by_external_entities_with_http_info(**kwargs)  # noqa: E501
            return data

    def change_mappings_by_external_entities_with_http_info(self, **kwargs):  # noqa: E501
        """Changes the mappings identified by their external ids.  # noqa: E501

        Changes the mappings identified by their external <code>id</code>s.<p>Changes the mappings identified by their external <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_by_external_entities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeMappingByExternalEntityRequest] body: The properties of the mappings to be changed.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mappings_by_external_entities" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/externalEntity/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Mapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_mappings_by_mapped_resources(self, **kwargs):  # noqa: E501
        """Changes the mapping identified by their external system ids and mapped resource ids.  # noqa: E501

        Changes the mapping identified by their external system <code>id</code>s and mapped resource <code>id</code>s.<p>Changes the mapping identified by their external system <code>id</code>s and mapped resource <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_by_mapped_resources(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeMappingByMappedResourceRequest] body: The properties of the mappings to be changed.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_mappings_by_mapped_resources_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.change_mappings_by_mapped_resources_with_http_info(**kwargs)  # noqa: E501
            return data

    def change_mappings_by_mapped_resources_with_http_info(self, **kwargs):  # noqa: E501
        """Changes the mapping identified by their external system ids and mapped resource ids.  # noqa: E501

        Changes the mapping identified by their external system <code>id</code>s and mapped resource <code>id</code>s.<p>Changes the mapping identified by their external system <code>id</code>s and mapped resource <code>id</code>s with the information that is present in the requests. Only properties that are specified in these requests and have not <code>null</code> values are updated. All other properties are ignored.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_mappings_by_mapped_resources_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeMappingByMappedResourceRequest] body: The properties of the mappings to be changed.
        :return: list[Mapping]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_mappings_by_mapped_resources" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/mappedResource/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Mapping]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_mappings(self, **kwargs):  # noqa: E501
        """Returns mappings matching the given search criteria.  # noqa: E501

        Returns mappings matching the given search criteria.<p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored.</p>The returned synchronization information satisfies all constraints that are specified in this search criteria. By default a result containing 1000 mappings is returned.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_mappings(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str external_system_id: The ID of the external system that the mapped resource belongs to.
        :param str external_entity_id: The external ID of the mapped resource.
        :param str mapped_resource_type: The type of the mapped resource.
        :param str sync_action: The type of the action performed during last successful synchronization.
        :return: MappingPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_mappings_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_mappings_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_mappings_with_http_info(self, **kwargs):  # noqa: E501
        """Returns mappings matching the given search criteria.  # noqa: E501

        Returns mappings matching the given search criteria.<p>Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored.</p>The returned synchronization information satisfies all constraints that are specified in this search criteria. By default a result containing 1000 mappings is returned.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_mappings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str external_system_id: The ID of the external system that the mapped resource belongs to.
        :param str external_entity_id: The external ID of the mapped resource.
        :param str mapped_resource_type: The type of the mapped resource.
        :param str sync_action: The type of the action performed during last successful synchronization.
        :return: MappingPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'external_system_id', 'external_entity_id', 'mapped_resource_type', 'sync_action']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_mappings" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'external_system_id' in params:
            query_params.append(('externalSystemId', params['external_system_id']))  # noqa: E501
        if 'external_entity_id' in params:
            query_params.append(('externalEntityId', params['external_entity_id']))  # noqa: E501
        if 'mapped_resource_type' in params:
            query_params.append(('mappedResourceType', params['mapped_resource_type']))  # noqa: E501
        if 'sync_action' in params:
            query_params.append(('syncAction', params['sync_action']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MappingPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_mapping(self, mapping_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by given id.  # noqa: E501

        Returns a mapping identified by given <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mapping_id: The id of the mapping. (required)
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501
            return data

    def get_mapping_with_http_info(self, mapping_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by given id.  # noqa: E501

        Returns a mapping identified by given <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_with_http_info(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mapping_id: The id of the mapping. (required)
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['mapping_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mapping" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `get_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'mapping_id' in params:
            path_params['mappingId'] = params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/{mappingId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_mapping_by_external_entity(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by its external ids.  # noqa: E501

        Returns a mapping identified by its external <code>id</code>s.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_by_external_entity(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: (required)
        :param str external_entity_id: (required)
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501
            return data

    def get_mapping_by_external_entity_with_http_info(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by its external ids.  # noqa: E501

        Returns a mapping identified by its external <code>id</code>s.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: (required)
        :param str external_entity_id: (required)
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_system_id', 'external_entity_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mapping_by_external_entity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if ('external_system_id' not in params or
                params['external_system_id'] is None):
            raise ValueError("Missing the required parameter `external_system_id` when calling `get_mapping_by_external_entity`")  # noqa: E501
        # verify the required parameter 'external_entity_id' is set
        if ('external_entity_id' not in params or
                params['external_entity_id'] is None):
            raise ValueError("Missing the required parameter `external_entity_id` when calling `get_mapping_by_external_entity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in params:
            path_params['externalSystemId'] = params['external_system_id']  # noqa: E501
        if 'external_entity_id' in params:
            path_params['externalEntityId'] = params['external_entity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/externalEntity/{externalEntityId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_mapping_by_mapped_resource(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by its external system id and mapped resource id.  # noqa: E501

        Returns a mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_by_mapped_resource(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: (required)
        :param str mapped_resource_id: (required)
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501
            return data

    def get_mapping_by_mapped_resource_with_http_info(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Returns a mapping identified by its external system id and mapped resource id.  # noqa: E501

        Returns a mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: (required)
        :param str mapped_resource_id: (required)
        :return: Mapping
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_system_id', 'mapped_resource_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mapping_by_mapped_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if ('external_system_id' not in params or
                params['external_system_id'] is None):
            raise ValueError("Missing the required parameter `external_system_id` when calling `get_mapping_by_mapped_resource`")  # noqa: E501
        # verify the required parameter 'mapped_resource_id' is set
        if ('mapped_resource_id' not in params or
                params['mapped_resource_id'] is None):
            raise ValueError("Missing the required parameter `mapped_resource_id` when calling `get_mapping_by_mapped_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in params:
            path_params['externalSystemId'] = params['external_system_id']  # noqa: E501
        if 'mapped_resource_id' in params:
            path_params['mappedResourceId'] = params['mapped_resource_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/mappedResource/{mappedResourceId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Mapping',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mapping(self, mapping_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its id.  # noqa: E501

        Removes the mapping identified by its <code>id</code>.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mapping_id: The id of the mapping. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_mapping_with_http_info(mapping_id, **kwargs)  # noqa: E501
            return data

    def remove_mapping_with_http_info(self, mapping_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its id.  # noqa: E501

        Removes the mapping identified by its <code>id</code>.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_with_http_info(mapping_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mapping_id: The id of the mapping. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['mapping_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mapping" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'mapping_id' is set
        if ('mapping_id' not in params or
                params['mapping_id'] is None):
            raise ValueError("Missing the required parameter `mapping_id` when calling `remove_mapping`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'mapping_id' in params:
            path_params['mappingId'] = params['mapping_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/{mappingId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mapping_by_external_entity(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its external ids.  # noqa: E501

        Removes the mapping identified by its external <code>id</code>s.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_by_external_entity(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The external system id of the mapping to be removed. (required)
        :param str external_entity_id: The external entity id of the mapping to be removed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, **kwargs)  # noqa: E501
            return data

    def remove_mapping_by_external_entity_with_http_info(self, external_system_id, external_entity_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its external ids.  # noqa: E501

        Removes the mapping identified by its external <code>id</code>s.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_by_external_entity_with_http_info(external_system_id, external_entity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The external system id of the mapping to be removed. (required)
        :param str external_entity_id: The external entity id of the mapping to be removed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_system_id', 'external_entity_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mapping_by_external_entity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if ('external_system_id' not in params or
                params['external_system_id'] is None):
            raise ValueError("Missing the required parameter `external_system_id` when calling `remove_mapping_by_external_entity`")  # noqa: E501
        # verify the required parameter 'external_entity_id' is set
        if ('external_entity_id' not in params or
                params['external_entity_id'] is None):
            raise ValueError("Missing the required parameter `external_entity_id` when calling `remove_mapping_by_external_entity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in params:
            path_params['externalSystemId'] = params['external_system_id']  # noqa: E501
        if 'external_entity_id' in params:
            path_params['externalEntityId'] = params['external_entity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/externalEntity/{externalEntityId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mapping_by_mapped_resource(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its external system id and mapped resource id.  # noqa: E501

        Removes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_by_mapped_resource(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The external system id of the mapping to be changed. (required)
        :param str mapped_resource_id: The mapped resource id of the mapping to be changed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, **kwargs)  # noqa: E501
            return data

    def remove_mapping_by_mapped_resource_with_http_info(self, external_system_id, mapped_resource_id, **kwargs):  # noqa: E501
        """Removes the mapping identified by its external system id and mapped resource id.  # noqa: E501

        Removes the mapping identified by its external system <code>id</code> and mapped resource <code>id</code>.<p>If the mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mapping_by_mapped_resource_with_http_info(external_system_id, mapped_resource_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The external system id of the mapping to be changed. (required)
        :param str mapped_resource_id: The mapped resource id of the mapping to be changed. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_system_id', 'mapped_resource_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mapping_by_mapped_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if ('external_system_id' not in params or
                params['external_system_id'] is None):
            raise ValueError("Missing the required parameter `external_system_id` when calling `remove_mapping_by_mapped_resource`")  # noqa: E501
        # verify the required parameter 'mapped_resource_id' is set
        if ('mapped_resource_id' not in params or
                params['mapped_resource_id'] is None):
            raise ValueError("Missing the required parameter `mapped_resource_id` when calling `remove_mapping_by_mapped_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in params:
            path_params['externalSystemId'] = params['external_system_id']  # noqa: E501
        if 'mapped_resource_id' in params:
            path_params['mappedResourceId'] = params['mapped_resource_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/mappedResource/{mappedResourceId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mappings_by_external_system_in_job(self, external_system_id, **kwargs):  # noqa: E501
        """Removes all the mappings identified by given external system id.  # noqa: E501

        Removes all the mappings identified by given external system <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mappings_by_external_system_in_job(external_system_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The id of the external system of the mappings that will be removed. (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_mappings_by_external_system_in_job_with_http_info(external_system_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_mappings_by_external_system_in_job_with_http_info(external_system_id, **kwargs)  # noqa: E501
            return data

    def remove_mappings_by_external_system_in_job_with_http_info(self, external_system_id, **kwargs):  # noqa: E501
        """Removes all the mappings identified by given external system id.  # noqa: E501

        Removes all the mappings identified by given external system <code>id</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mappings_by_external_system_in_job_with_http_info(external_system_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str external_system_id: The id of the external system of the mappings that will be removed. (required)
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['external_system_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mappings_by_external_system_in_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'external_system_id' is set
        if ('external_system_id' not in params or
                params['external_system_id'] is None):
            raise ValueError("Missing the required parameter `external_system_id` when calling `remove_mappings_by_external_system_in_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'external_system_id' in params:
            path_params['externalSystemId'] = params['external_system_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/externalSystem/{externalSystemId}/removalJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_mappings_in_job(self, **kwargs):  # noqa: E501
        """Removes multiple mappings in job.  # noqa: E501

        Removes multiple mappings in job.<p>If any mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mappings_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: The ids of the mappings to be removed.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_mappings_in_job_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.remove_mappings_in_job_with_http_info(**kwargs)  # noqa: E501
            return data

    def remove_mappings_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Removes multiple mappings in job.  # noqa: E501

        Removes multiple mappings in job.<p>If any mapping does not exist, an exception is NOT thrown.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_mappings_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: The ids of the mappings to be removed.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_mappings_in_job" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/mappings/removalJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
